package RTF::HTML::Converter::ansi;
$RTF::HTML::Converter::ansi::VERSION = '1.10';
use strict;
use warnings;

my @data = (<DATA>);
chomp(@data);

sub data {

    return @data;

}

1;

__DATA__
00 ` 
01 &acute;
02 ^
03 ~
04 &shy;
05 &shy;
06 &deg;
07 &uml;
08 &middot;
20 --
30 _
82 ,
83 f
84 ,,
85 ...
86 +
87 ++
88 ^
89 0/00
8a S
8b <
8c OE
91 `
92 '
93 ``
94 ''
95 &middot;
96 -
97 --
98 ~
99 [tm]
9a s
9b >
9c oe
9f Y
